/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.area;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import nl.cloudfarming.client.geoviewer.Layer;
import nl.cloudfarming.client.geoviewer.LayerProvider;
import nl.cloudfarming.client.geoviewer.Palette;
import nl.cloudfarming.client.sensor.SensorDataLayerProvider;
import org.openide.util.Lookup;
import org.openide.util.lookup.AbstractLookup;
import org.openide.util.lookup.InstanceContent;
import org.openide.util.lookup.ServiceProvider;
import org.openide.util.lookup.ServiceProviders;

/**
 *
 * @author Timon Veenstra
 */
//@ServiceProviders(value = {
//    @ServiceProvider(service = LayerProvider.class),
//    @ServiceProvider(service = SensorDataLayerProvider.class)})
public class AreaSensorDataLayerProvider implements SensorDataLayerProvider {

    private final InstanceContent lookupContent = new InstanceContent();
    private final Lookup lookup = new AbstractLookup(lookupContent);
    private final List<Layer<?>> layers = new ArrayList<Layer<?>>();

    public AreaSensorDataLayerProvider() {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(new Date());

        add(new AreaSensorDataLayer(AreaSensorDataLayerObject.KeyAttribute.Vi1));

    }

    private void add(Layer<?> layer) {
        this.lookupContent.add(layer);
        this.layers.add(layer);
    }

    @Override
    public void changePalette(Palette pallete) {
        for (Layer<?> layer : this.layers) {
            layer.setPalette(pallete);
        }
    }

    @Override
    public Lookup getLookup() {
        return this.lookup;
    }
}
